


const path = require('node:path');
const { Pact, Matchers } = require('@pact-foundation/pact');
const axios = require('axios');

async function main() {

    const provider = new Pact({
        consumer: 'consumer',
        provider: 'provider',
        dir: path.resolve('pacts'),
        spec: 2,
        logLevel: 'debug'
    });


    await provider.setup();

    const request = {
        data: 'some string'
    };

    const expected_response = {
        ...request,
        event_id: '37227fda-94d3-4422-908d-fe2303914e98',
        posted_date: '2021-03-17T07:52:34.666Z'
    };

    for (let i = 0; i < 100; i += 1) {
        await provider.addInteraction({
            state: undefined,
            uponReceiving: `a post to the event bus - ${i}`,
            willRespondWith: {
                body: {
                    data: Matchers.string(expected_response.data),
                    event_id: Matchers.string(expected_response.event_id),
                    posted_date: Matchers.iso8601DateTimeWithMillis(expected_response.posted_date),
                },
                headers: {
                    'Content-Type': 'application/json',
                },
                status: 201 
            },
            withRequest: {
                body: request,
                headers: {
                    'Content-Type': 'application/json',
                },
                method: 'POST',
                path: '/endpoint'
            }
        });
    
        const client = axios.create({ baseURL: provider.mockService.baseUrl });
        const { data } = await client.post('/endpoint', request);
        console.dir({ request, expected_response, data }, { depth: null });
    
        await provider.verify();

        // global.gc();
    }
    await provider.finalize();

    console.log("**** DONE ****");

}

main().catch(err => {
    console.log('error: ', err)
    process.exitCode = 1;
})
